pub struct PropagatorConfig {
pub method: IntegratorMethod,
pub options: IntegratorOptions,
pub accel_models: AccelModels,
pub force_models: ForceModels,
}Expand description
Propagator config includes the method, options, and all dynamics
Fields
method: IntegratorMethodoptions: IntegratorOptionsaccel_models: AccelModelsforce_models: ForceModelsTrait Implementations
Sourceimpl Clone for PropagatorConfig
impl Clone for PropagatorConfig
Sourcefn clone(&self) -> PropagatorConfig
fn clone(&self) -> PropagatorConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PropagatorConfig
impl Debug for PropagatorConfig
impl DerefToPyAny for PropagatorConfig
Sourceimpl<'de> Deserialize<'de> for PropagatorConfig
impl<'de> Deserialize<'de> for PropagatorConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PropagatorConfigwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PropagatorConfigwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PropagatorConfig
impl<'py> IntoPyObject<'py> for PropagatorConfig
Sourcetype Target = PropagatorConfig
type Target = PropagatorConfig
The Python output type
Sourcetype Output = Bound<'py, <PropagatorConfig as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PropagatorConfig as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PropagatorConfig
impl PyClass for PropagatorConfig
Sourceimpl PyClassImpl for PropagatorConfig
impl PyClassImpl for PropagatorConfig
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Propagator config includes the method, options, and all dynamics
const RAW_DOC: &'static CStr = /// Propagator config includes the method, options, and all dynamics
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PropagatorConfig as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PropagatorConfig>
type Layout = <<PropagatorConfig as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PropagatorConfig>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPropagatorConfig
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyTypeInfo for PropagatorConfig
impl PyTypeInfo for PropagatorConfig
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for PropagatorConfig
impl Serialize for PropagatorConfig
Sourceimpl StaticType for PropagatorConfig
impl StaticType for PropagatorConfig
Sourcefn static_type() -> SimpleType
fn static_type() -> SimpleType
Return the Dhall type that represents this type. Read more